Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(344)

Unified Diff: components/exo/keyboard.cc

Issue 2909763002: Revert of Rename MaximizeMode to TabletMode (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/exo/keyboard.h ('k') | components/exo/shell_surface.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/exo/keyboard.cc
diff --git a/components/exo/keyboard.cc b/components/exo/keyboard.cc
index 5359c84d5f334659315edeb93e6b9ed5ce668315..fd261e1ec9dc0aee123cddf5def1db6844d62f5f 100644
--- a/components/exo/keyboard.cc
+++ b/components/exo/keyboard.cc
@@ -75,8 +75,8 @@
}
bool IsPhysicalKeyboardEnabled() {
- // The internal keyboard is enabled if tablet mode is not enabled.
- if (!WMHelper::GetInstance()->IsTabletModeWindowManagerEnabled())
+ // The internal keyboard is enabled if maximize mode is not enabled.
+ if (!WMHelper::GetInstance()->IsMaximizeModeWindowManagerEnabled())
return true;
for (auto& keyboard :
@@ -96,7 +96,7 @@
auto* helper = WMHelper::GetInstance();
helper->AddPostTargetHandler(this);
helper->AddFocusObserver(this);
- helper->AddTabletModeObserver(this);
+ helper->AddMaximizeModeObserver(this);
helper->AddInputDeviceEventObserver(this);
OnWindowFocused(helper->GetFocusedWindow(), nullptr);
}
@@ -110,7 +110,7 @@
auto* helper = WMHelper::GetInstance();
helper->RemoveFocusObserver(this);
helper->RemovePostTargetHandler(this);
- helper->RemoveTabletModeObserver(this);
+ helper->RemoveMaximizeModeObserver(this);
helper->RemoveInputDeviceEventObserver(this);
}
@@ -215,15 +215,15 @@
}
////////////////////////////////////////////////////////////////////////////////
-// WMHelper::TabletModeObserver overrides:
-
-void Keyboard::OnTabletModeStarted() {
+// WMHelper::MaximizeModeObserver overrides:
+
+void Keyboard::OnMaximizeModeStarted() {
OnKeyboardDeviceConfigurationChanged();
}
-void Keyboard::OnTabletModeEnding() {}
-
-void Keyboard::OnTabletModeEnded() {
+void Keyboard::OnMaximizeModeEnding() {}
+
+void Keyboard::OnMaximizeModeEnded() {
OnKeyboardDeviceConfigurationChanged();
}
« no previous file with comments | « components/exo/keyboard.h ('k') | components/exo/shell_surface.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698